﻿namespace ProjectGasMachine.CollectionGenericObjects;

/// <summary>
/// класс-хранилище
/// </summary>
/// <typeparam name="T"></typeparam>
public class StorageCollection<T>
    where T : class
{
    /// <summary>
    /// словарь (хранилище) с коллекциями
    /// </summary>
    private Dictionary<string, ICollectionGenericObjects<T>> _storages;

    /// <summary>
    /// Возвращение списка названий коллекций
    /// </summary>
    public List<string> Keys => _storages.Keys.ToList();

    /// <summary>
    /// конструктор
    /// </summary>
    public StorageCollection() 
    {
        _storages = new Dictionary<string, ICollectionGenericObjects<T>>();
    }

    /// <summary>
    /// добваление коллекции в хранилище
    /// </summary>
    /// <param name="name">название коллекции</param>
    /// <param name="collectionType">тип коллекции</param>
    public void AddCollection(string name, CollectionType collectionType) 
    {
        if (name == null || _storages.ContainsKey(name)) 
        {
            return;
        }

        if (collectionType == CollectionType.Massive)
        {
            _storages.Add(name, new MassiveGenericObjects<T>());
        }

        if (collectionType == CollectionType.List)
        {
            _storages.Add(name, new ListGenericObjects<T>());
        }
    }

    /// <summary>
    /// Удаление коллекции
    /// </summary>
    /// <param name="name"></param>
    public void DelCollection(string name) 
    {
        if (name == null || !_storages.ContainsKey(name)) 
        {
            return;
        }

        _storages.Remove(name);
    }

    /// <summary>
    /// Доступ к коллекции
    /// </summary>
    /// <param name="name">Название коллекции</param>
    /// <returns></returns>
    public ICollectionGenericObjects<T>? this[string name] 
    {
        get 
        {
            if (_storages.ContainsKey(name)) 
            {
                return _storages[name];
            }

            return null;
        }
    }

}
